@@ -51,7 +51,7 @@ class CreateBookInput(MutationSchema):
     title: str
     author: str
     price: Decimal
-    location_ids: list[int] = []
+    locations: list[t.Union[int, list[int, int]]] = []
     is_backorder: bool = True
     product_type: str = "Textbook"
     subtitle: t.Optional[str] = None
@@ -126,15 +126,18 @@ class CreateBookInput(MutationSchema):
         }
         if self.cover_image:
             data["images"] = [{"altText": self.title, "src": self.cover_image}]
-        if self.location_ids:
+        if self.locations:
             data["variants"][0]["inventoryPolicy"] = "CONTINUE"
-            data["variants"][0]["inventoryQuantities"] = [
-                {
-                    "locationId": f"gid://shopify/Location/{location_id}",
-                    "availableQuantity": 100,
-                }
-                for location_id in self.location_ids
-            ]
+            for location in self.locations:
+                if isinstance(location, int):
+                    location = [location, 0]
+                location_id, quantity = location
+                data["variants"][0]["inventoryQuantities"].append(
+                    {
+                        "locationId": f"gid://shopify/Location/{location_id}",
+                        "availableQuantity": quantity,
+                    }
+                )
         return data
 
 
